<?php

namespace App\Http\Controllers;

use Exception;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use TCG\Voyager\Database\Schema\SchemaManager;
use TCG\Voyager\Events\BreadDataAdded;
use TCG\Voyager\Events\BreadDataDeleted;
use TCG\Voyager\Events\BreadDataRestored;
use TCG\Voyager\Events\BreadDataUpdated;
use TCG\Voyager\Events\BreadImagesDeleted;
use TCG\Voyager\Facades\Voyager;
use TCG\Voyager\Http\Controllers\Traits\BreadRelationshipParser;
use TCG\Voyager\Http\Controllers\VoyagerBaseController;
use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xls;
use PhpOffice\PhpSpreadsheet\IOFactory;
use Illuminate\Support\Facades\Validator;
use Yajra\Datatables\Datatables;
use App\Project;
use App\ProjectEvent;
use App\ProjectTimeline;
use Barryvdh\DomPDF\Facade\Pdf;
use Carbon\Carbon;

class ProjectController extends VoyagerBaseController
{
    use BreadRelationshipParser;

    //***************************************
    //               ____
    //              |  _ \
    //              | |_) |
    //              |  _ <
    //              | |_) |
    //              |____/
    //
    //      Browse our Data Type (B)READ
    //
    //****************************************

    public function index(Request $request)
    {
       // echo Carbon::createFromFormat('d/m/Y', "13/11/2019")->format('Y-m-d');
        //dd(auth()->user()->hasRole('admin'));
       // dd(auth()->user()->subscriptionPlan());
        // GET THE SLUG, ex. 'posts', 'pages', etc.
        $slug = $this->getSlug($request);

        // GET THE DataType based on the slug
        $dataType = Voyager::model('DataType')->where('slug', '=', $slug)->first();

        // Check permission
        $this->authorize('browse', app($dataType->model_name));

        $projects = Project::where("user_id",Auth::user()->id)->count();

        return view("projects.list", compact(
            'dataType','projects'
        ));
    }

    //***************************************
    //                _____
    //               |  __ \
    //               | |__) |
    //               |  _  /
    //               | | \ \
    //               |_|  \_\
    //
    //  Read an item of our Data Type B(R)EAD
    //
    //****************************************

    public function show(Request $request, $id)
    {
        return Project::where("user_id",Auth::User()->id)->where("id",$id)->first();
        $slug = $this->getSlug($request);

        $dataType = Voyager::model('DataType')->where('slug', '=', $slug)->first();

        $isSoftDeleted = false;

        if (strlen($dataType->model_name) != 0) {
            $model = app($dataType->model_name);
            $query = $model->query();

            // Use withTrashed() if model uses SoftDeletes and if toggle is selected
            if ($model && in_array(SoftDeletes::class, class_uses_recursive($model))) {
                $query = $query->withTrashed();
            }
            if ($dataType->scope && $dataType->scope != '' && method_exists($model, 'scope'.ucfirst($dataType->scope))) {
                $query = $query->{$dataType->scope}();
            }
            $dataTypeContent = call_user_func([$query, 'findOrFail'], $id);
            if ($dataTypeContent->deleted_at) {
                $isSoftDeleted = true;
            }
        } else {
            // If Model doest exist, get data from table name
            $dataTypeContent = DB::table($dataType->name)->where('id', $id)->first();
        }

        // Replace relationships' keys for labels and create READ links if a slug is provided.
        $dataTypeContent = $this->resolveRelations($dataTypeContent, $dataType, true);

        // If a column has a relationship associated with it, we do not want to show that field
        $this->removeRelationshipField($dataType, 'read');

        // Check permission
        $this->authorize('read', $dataTypeContent);

        // Check if BREAD is Translatable
        $isModelTranslatable = is_bread_translatable($dataTypeContent);

        // Eagerload Relations
        $this->eagerLoadRelations($dataTypeContent, $dataType, 'read', $isModelTranslatable);

        $view = 'voyager::bread.read';

        if (view()->exists("voyager::$slug.read")) {
            $view = "voyager::$slug.read";
        }

        return Voyager::view($view, compact('dataType', 'dataTypeContent', 'isModelTranslatable', 'isSoftDeleted'));
    }

    //***************************************
    //                ______
    //               |  ____|
    //               | |__
    //               |  __|
    //               | |____
    //               |______|
    //
    //  Edit an item of our Data Type BR(E)AD
    //
    //****************************************

    public function edit(Request $request, $id)
    {
        $slug = $this->getSlug($request);

        $dataType = Voyager::model('DataType')->where('slug', '=', $slug)->first();

        if (strlen($dataType->model_name) != 0) {
            $model = app($dataType->model_name);
            $query = $model->query();

            // Use withTrashed() if model uses SoftDeletes and if toggle is selected
            if ($model && in_array(SoftDeletes::class, class_uses_recursive($model))) {
                $query = $query->withTrashed();
            }
            if ($dataType->scope && $dataType->scope != '' && method_exists($model, 'scope'.ucfirst($dataType->scope))) {
                $query = $query->{$dataType->scope}();
            }
            $dataTypeContent = call_user_func([$query, 'findOrFail'], $id);
        } else {
            // If Model doest exist, get data from table name
            $dataTypeContent = DB::table($dataType->name)->where('id', $id)->first();
        }

        foreach ($dataType->editRows as $key => $row) {
            $dataType->editRows[$key]['col_width'] = isset($row->details->width) ? $row->details->width : 100;
        }

        // If a column has a relationship associated with it, we do not want to show that field
        $this->removeRelationshipField($dataType, 'edit');

        // Check permission
        $this->authorize('edit', $dataTypeContent);

        // Check if BREAD is Translatable
        $isModelTranslatable = is_bread_translatable($dataTypeContent);

        // Eagerload Relations
        $this->eagerLoadRelations($dataTypeContent, $dataType, 'edit', $isModelTranslatable);

        $view = 'voyager::bread.edit-add';

        if (view()->exists("voyager::$slug.edit-add")) {
            $view = "voyager::$slug.edit-add";
        }

        return Voyager::view($view, compact('dataType', 'dataTypeContent', 'isModelTranslatable'));
    }

    // POST BR(E)AD
    public function update(Request $request, $id)
    {
        $slug = $this->getSlug($request);

        $dataType = Voyager::model('DataType')->where('slug', '=', $slug)->first();

        // Compatibility with Model binding.
        $id = $id instanceof \Illuminate\Database\Eloquent\Model ? $id->{$id->getKeyName()} : $id;

        $model = app($dataType->model_name);
        $query = $model->query();
        if ($dataType->scope && $dataType->scope != '' && method_exists($model, 'scope'.ucfirst($dataType->scope))) {
            $query = $query->{$dataType->scope}();
        }
        if ($model && in_array(SoftDeletes::class, class_uses_recursive($model))) {
            $query = $query->withTrashed();
        }

        $data = $query->findOrFail($id);

        // Check permission
        $this->authorize('edit', $data);

        // Validate fields with ajax
        $val = $this->validateBread($request->all(), $dataType->editRows, $dataType->name, $id)->validate();

        // Get fields with images to remove before updating and make a copy of $data
        $to_remove = $dataType->editRows->where('type', 'image')
            ->filter(function ($item, $key) use ($request) {
                return $request->hasFile($item->field);
            });
        $original_data = clone($data);

        $this->insertUpdateData($request, $slug, $dataType->editRows, $data);

        // Delete Images
        $this->deleteBreadImages($original_data, $to_remove);

        event(new BreadDataUpdated($dataType, $data));

        if (auth()->user()->can('browse', app($dataType->model_name))) {
            $redirect = redirect()->route("voyager.{$dataType->slug}.index");
        } else {
            $redirect = redirect()->back();
        }

        return $redirect->with([
            'message'    => __('voyager::generic.successfully_updated')." {$dataType->getTranslatedAttribute('display_name_singular')}",
            'alert-type' => 'success',
        ]);
    }

    //***************************************
    //
    //                   /\
    //                  /  \
    //                 / /\ \
    //                / ____ \
    //               /_/    \_\
    //
    //
    // Add a new item of our Data Type BRE(A)D
    //
    //****************************************

    public function create(Request $request)
    {
        $slug = $this->getSlug($request);

        $dataType = Voyager::model('DataType')->where('slug', '=', $slug)->first();

        // Check permission
        $this->authorize('add', app($dataType->model_name));

        $dataTypeContent = (strlen($dataType->model_name) != 0)
                            ? new $dataType->model_name()
                            : false;

        foreach ($dataType->addRows as $key => $row) {
            $dataType->addRows[$key]['col_width'] = $row->details->width ?? 100;
        }

        // If a column has a relationship associated with it, we do not want to show that field
        $this->removeRelationshipField($dataType, 'add');

        // Check if BREAD is Translatable
        $isModelTranslatable = is_bread_translatable($dataTypeContent);

        // Eagerload Relations
        $this->eagerLoadRelations($dataTypeContent, $dataType, 'add', $isModelTranslatable);

        $view = 'voyager::bread.edit-add';

        if (view()->exists("voyager::$slug.edit-add")) {
            $view = "voyager::$slug.edit-add";
        }

        return Voyager::view($view, compact('dataType', 'dataTypeContent', 'isModelTranslatable'));
    }

    /**
     * POST BRE(A)D - Store data.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse
     */
    public function store(Request $request)
    {
       $project = new Project;
       //dd($request->all());
       if($request->id!='')
       {
            $project = $project->findOrFail($request->id);
       }else
       {
             $validator = Validator::make($request->all(), [
             'file' => ['required'],
                'file.*' => ['required',"mimes:csv"]
            
            ]);
            if ($validator->fails()) {
               // var_dump($request->file->getClientMimeType());
                $error = $validator->errors()->all();
                //dd($error);
                return response()->json(['success'=>false,"message"=>$error[0]]);
            }
       }
      $project->fill($request->all());
       $project->user_id = Auth::User()->id;
       if($project->save())
       {
            if($request->id=='')
           {
                   $the_file = $request->file('file');
                   try{
                           $spreadsheet = IOFactory::load($the_file->getRealPath());
                           $sheet        = $spreadsheet->getActiveSheet()->toArray();
                          
                           $startcount = 2;
                           $data = array();
                           unset($sheet[0]);
                           foreach ( $sheet as $row ) {
                             //  dd($row);
                            // dd(Carbon::createFromFormat('d/m/Y', $row[0])->format('Y-m-d'));
                               $event = new ProjectEvent; 
                               $event->edate = Carbon::createFromFormat('d/m/Y', $row[0])->format('Y-m-d');
                               $event->event = $row[1];
                               
                               $event->pid = $project->id;
                               $event->save();
                           }
                            
                        } catch (Exception $e) {
                            
                             return response()->json(['success'=>false,"message"=>$e->getMessage()]);
                        }
           }
            return response()->json(['success'=>true,"message"=>"Project Successfully saved!"]);    
       }else
       {
         return response()->json(['success'=>true,"message"=>"error while saving project!"]);    
       }
       
    }

    //***************************************
    //                _____
    //               |  __ \
    //               | |  | |
    //               | |  | |
    //               | |__| |
    //               |_____/
    //
    //         Delete an item BREA(D)
    //
    //****************************************

    public function destroy(Request $request, $id)
    {
        $slug = $this->getSlug($request);

        $dataType = Voyager::model('DataType')->where('slug', '=', $slug)->first();

        // Init array of IDs
        $ids = [];
        if (empty($id)) {
            // Bulk delete, get IDs from POST
            $ids = explode(',', $request->ids);
        } else {
            // Single item delete, get ID from URL
            $ids[] = $id;
        }
        foreach ($ids as $id) {
            $data = call_user_func([$dataType->model_name, 'findOrFail'], $id);

            // Check permission
            $this->authorize('delete', $data);

            $model = app($dataType->model_name);
            if (!($model && in_array(SoftDeletes::class, class_uses_recursive($model)))) {
                $this->cleanup($dataType, $data);
            }
        }

        $displayName = count($ids) > 1 ? $dataType->getTranslatedAttribute('display_name_plural') : $dataType->getTranslatedAttribute('display_name_singular');

        $res = $data->destroy($ids);
        $data = $res
            ? [
                'message'    => __('voyager::generic.successfully_deleted')." {$displayName}",
                'alert-type' => 'success',
            ]
            : [
                'message'    => __('voyager::generic.error_deleting')." {$displayName}",
                'alert-type' => 'error',
            ];

        if ($res) {
            event(new BreadDataDeleted($dataType, $data));
        }

        return redirect()->route("voyager.{$dataType->slug}.index")->with($data);
    }

    public function restore(Request $request, $id)
    {
        $slug = $this->getSlug($request);

        $dataType = Voyager::model('DataType')->where('slug', '=', $slug)->first();

        // Check permission
        $model = app($dataType->model_name);
        $this->authorize('delete', $model);

        // Get record
        $query = $model->withTrashed();
        if ($dataType->scope && $dataType->scope != '' && method_exists($model, 'scope'.ucfirst($dataType->scope))) {
            $query = $query->{$dataType->scope}();
        }
        $data = $query->findOrFail($id);

        $displayName = $dataType->getTranslatedAttribute('display_name_singular');

        $res = $data->restore($id);
        $data = $res
            ? [
                'message'    => __('voyager::generic.successfully_restored')." {$displayName}",
                'alert-type' => 'success',
            ]
            : [
                'message'    => __('voyager::generic.error_restoring')." {$displayName}",
                'alert-type' => 'error',
            ];

        if ($res) {
            event(new BreadDataRestored($dataType, $data));
        }

        return redirect()->route("voyager.{$dataType->slug}.index")->with($data);
    }

    //***************************************
    //
    //  Delete uploaded file
    //
    //****************************************

    public function remove_media(Request $request)
    {
        try {
            // GET THE SLUG, ex. 'posts', 'pages', etc.
            $slug = $request->get('slug');

            // GET file name
            $filename = $request->get('filename');

            // GET record id
            $id = $request->get('id');

            // GET field name
            $field = $request->get('field');

            // GET multi value
            $multi = $request->get('multi');

            $dataType = Voyager::model('DataType')->where('slug', '=', $slug)->first();

            // Load model and find record
            $model = app($dataType->model_name);
            $data = $model::find([$id])->first();

            // Check if field exists
            if (!isset($data->{$field})) {
                throw new Exception(__('voyager::generic.field_does_not_exist'), 400);
            }

            // Check permission
            $this->authorize('edit', $data);

            if (@json_decode($multi)) {
                // Check if valid json
                if (is_null(@json_decode($data->{$field}))) {
                    throw new Exception(__('voyager::json.invalid'), 500);
                }

                // Decode field value
                $fieldData = @json_decode($data->{$field}, true);
                $key = null;

                // Check if we're dealing with a nested array for the case of multiple files
                if (is_array($fieldData[0])) {
                    foreach ($fieldData as $index=>$file) {
                        // file type has a different structure than images
                        if (!empty($file['original_name'])) {
                            if ($file['original_name'] == $filename) {
                                $key = $index;
                                break;
                            }
                        } else {
                            $file = array_flip($file);
                            if (array_key_exists($filename, $file)) {
                                $key = $index;
                                break;
                            }
                        }
                    }
                } else {
                    $key = array_search($filename, $fieldData);
                }

                // Check if file was found in array
                if (is_null($key) || $key === false) {
                    throw new Exception(__('voyager::media.file_does_not_exist'), 400);
                }

                $fileToRemove = $fieldData[$key]['download_link'] ?? $fieldData[$key];

                // Remove file from array
                unset($fieldData[$key]);

                // Generate json and update field
                $data->{$field} = empty($fieldData) ? null : json_encode(array_values($fieldData));
            } else {
                if ($filename == $data->{$field}) {
                    $fileToRemove = $data->{$field};

                    $data->{$field} = null;
                } else {
                    throw new Exception(__('voyager::media.file_does_not_exist'), 400);
                }
            }

            $row = $dataType->rows->where('field', $field)->first();

            // Remove file from filesystem
            if (in_array($row->type, ['image', 'multiple_images'])) {
                $this->deleteBreadImages($data, [$row], $fileToRemove);
            } else {
                $this->deleteFileIfExists($fileToRemove);
            }

            $data->save();

            return response()->json([
                'data' => [
                    'status'  => 200,
                    'message' => __('voyager::media.file_removed'),
                ],
            ]);
        } catch (Exception $e) {
            $code = 500;
            $message = __('voyager::generic.internal_error');

            if ($e->getCode()) {
                $code = $e->getCode();
            }

            if ($e->getMessage()) {
                $message = $e->getMessage();
            }

            return response()->json([
                'data' => [
                    'status'  => $code,
                    'message' => $message,
                ],
            ], $code);
        }
    }

    /**
     * Remove translations, images and files related to a BREAD item.
     *
     * @param \Illuminate\Database\Eloquent\Model $dataType
     * @param \Illuminate\Database\Eloquent\Model $data
     *
     * @return void
     */
    protected function cleanup($dataType, $data)
    {
        // Delete Translations, if present
        if (is_bread_translatable($data)) {
            $data->deleteAttributeTranslations($data->getTranslatableAttributes());
        }

        // Delete Images
        $this->deleteBreadImages($data, $dataType->deleteRows->whereIn('type', ['image', 'multiple_images']));

        // Delete Files
        foreach ($dataType->deleteRows->where('type', 'file') as $row) {
            if (isset($data->{$row->field})) {
                foreach (json_decode($data->{$row->field}) as $file) {
                    $this->deleteFileIfExists($file->download_link);
                }
            }
        }

        // Delete media-picker files
        $dataType->rows->where('type', 'media_picker')->where('details.delete_files', true)->each(function ($row) use ($data) {
            $content = $data->{$row->field};
            if (isset($content)) {
                if (!is_array($content)) {
                    $content = json_decode($content);
                }
                if (is_array($content)) {
                    foreach ($content as $file) {
                        $this->deleteFileIfExists($file);
                    }
                } else {
                    $this->deleteFileIfExists($content);
                }
            }
        });
    }

    /**
     * Delete all images related to a BREAD item.
     *
     * @param \Illuminate\Database\Eloquent\Model $data
     * @param \Illuminate\Database\Eloquent\Model $rows
     *
     * @return void
     */
    public function deleteBreadImages($data, $rows, $single_image = null)
    {
        $imagesDeleted = false;

        foreach ($rows as $row) {
            if ($row->type == 'multiple_images') {
                $images_to_remove = json_decode($data->getOriginal($row->field), true) ?? [];
            } else {
                $images_to_remove = [$data->getOriginal($row->field)];
            }

            foreach ($images_to_remove as $image) {
                // Remove only $single_image if we are removing from bread edit
                if ($image != config('voyager.user.default_avatar') && (is_null($single_image) || $single_image == $image)) {
                    $this->deleteFileIfExists($image);
                    $imagesDeleted = true;

                    if (isset($row->details->thumbnails)) {
                        foreach ($row->details->thumbnails as $thumbnail) {
                            $ext = explode('.', $image);
                            $extension = '.'.$ext[count($ext) - 1];

                            $path = str_replace($extension, '', $image);

                            $thumb_name = $thumbnail->name;

                            $this->deleteFileIfExists($path.'-'.$thumb_name.$extension);
                        }
                    }
                }
            }
        }

        if ($imagesDeleted) {
            event(new BreadImagesDeleted($data, $rows));
        }
    }

    /**
     * Order BREAD items.
     *
     * @param string $table
     *
     * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function order(Request $request)
    {
        $slug = $this->getSlug($request);

        $dataType = Voyager::model('DataType')->where('slug', '=', $slug)->first();

        // Check permission
        $this->authorize('edit', app($dataType->model_name));

        if (empty($dataType->order_column) || empty($dataType->order_display_column)) {
            return redirect()
            ->route("voyager.{$dataType->slug}.index")
            ->with([
                'message'    => __('voyager::bread.ordering_not_set'),
                'alert-type' => 'error',
            ]);
        }

        $model = app($dataType->model_name);
        $query = $model->query();
        if ($model && in_array(SoftDeletes::class, class_uses_recursive($model))) {
            $query = $query->withTrashed();
        }
        $results = $query->orderBy($dataType->order_column, $dataType->order_direction)->get();

        $display_column = $dataType->order_display_column;

        $dataRow = Voyager::model('DataRow')->whereDataTypeId($dataType->id)->whereField($display_column)->first();

        $view = 'voyager::bread.order';

        if (view()->exists("voyager::$slug.order")) {
            $view = "voyager::$slug.order";
        }

        return Voyager::view($view, compact(
            'dataType',
            'display_column',
            'dataRow',
            'results'
        ));
    }

    public function update_order(Request $request)
    {
        $slug = $this->getSlug($request);

        $dataType = Voyager::model('DataType')->where('slug', '=', $slug)->first();

        // Check permission
        $this->authorize('edit', app($dataType->model_name));

        $model = app($dataType->model_name);

        $order = json_decode($request->input('order'));
        $column = $dataType->order_column;
        foreach ($order as $key => $item) {
            if ($model && in_array(SoftDeletes::class, class_uses_recursive($model))) {
                $i = $model->withTrashed()->findOrFail($item->id);
            } else {
                $i = $model->findOrFail($item->id);
            }
            $i->$column = ($key + 1);
            $i->save();
        }
    }

    public function action(Request $request)
    {
        $slug = $this->getSlug($request);
        $dataType = Voyager::model('DataType')->where('slug', '=', $slug)->first();

        $action = new $request->action($dataType, null);

        return $action->massAction(explode(',', $request->ids), $request->headers->get('referer'));
    }

    /**
     * Get BREAD relations data.
     *
     * @param Request $request
     *
     * @return mixed
     */
    public function relation(Request $request)
    {
        $slug = $this->getSlug($request);
        $page = $request->input('page');
        $on_page = 50;
        $search = $request->input('search', false);
        $dataType = Voyager::model('DataType')->where('slug', '=', $slug)->first();

        $method = $request->input('method', 'add');

        $model = app($dataType->model_name);
        if ($method != 'add') {
            $model = $model->find($request->input('id'));
        }

        $this->authorize($method, $model);

        $rows = $dataType->{$method.'Rows'};
        foreach ($rows as $key => $row) {
            if ($row->field === $request->input('type')) {
                $options = $row->details;
                $model = app($options->model);
                $skip = $on_page * ($page - 1);

                $additional_attributes = $model->additional_attributes ?? [];

                // Apply local scope if it is defined in the relationship-options
                if (isset($options->scope) && $options->scope != '' && method_exists($model, 'scope'.ucfirst($options->scope))) {
                    $model = $model->{$options->scope}();
                }

                // If search query, use LIKE to filter results depending on field label
                if ($search) {
                    // If we are using additional_attribute as label
                    if (in_array($options->label, $additional_attributes)) {
                        $relationshipOptions = $model->get();
                        $relationshipOptions = $relationshipOptions->filter(function ($model) use ($search, $options) {
                            return stripos($model->{$options->label}, $search) !== false;
                        });
                        $total_count = $relationshipOptions->count();
                        $relationshipOptions = $relationshipOptions->forPage($page, $on_page);
                    } else {
                        $total_count = $model->where($options->label, 'LIKE', '%'.$search.'%')->count();
                        $relationshipOptions = $model->take($on_page)->skip($skip)
                            ->where($options->label, 'LIKE', '%'.$search.'%')
                            ->get();
                    }
                } else {
                    $total_count = $model->count();
                    $relationshipOptions = $model->take($on_page)->skip($skip)->get();
                }

                $results = [];

                if (!$row->required && !$search && $page == 1) {
                    $results[] = [
                        'id'   => '',
                        'text' => __('voyager::generic.none'),
                    ];
                }

                // Sort results
                if (!empty($options->sort->field)) {
                    if (!empty($options->sort->direction) && strtolower($options->sort->direction) == 'desc') {
                        $relationshipOptions = $relationshipOptions->sortByDesc($options->sort->field);
                    } else {
                        $relationshipOptions = $relationshipOptions->sortBy($options->sort->field);
                    }
                }

                foreach ($relationshipOptions as $relationshipOption) {
                    $results[] = [
                        'id'   => $relationshipOption->{$options->key},
                        'text' => $relationshipOption->{$options->label},
                    ];
                }

                return response()->json([
                    'results'    => $results,
                    'pagination' => [
                        'more' => ($total_count > ($skip + $on_page)),
                    ],
                ]);
            }
        }

        // No result found, return empty array
        return response()->json([], 404);
    }

    protected function findSearchableRelationshipRow($relationshipRows, $searchKey)
    {
        return $relationshipRows->filter(function ($item) use ($searchKey) {
            if ($item->details->column != $searchKey) {
                return false;
            }
            if ($item->details->type != 'belongsTo') {
                return false;
            }

            return !$this->relationIsUsingAccessorAsLabel($item->details);
        })->first();
    }

    protected function getSortableColumns($rows)
    {
        return $rows->filter(function ($item) {
            if ($item->type != 'relationship') {
                return true;
            }
            if ($item->details->type != 'belongsTo') {
                return false;
            }

            return !$this->relationIsUsingAccessorAsLabel($item->details);
        })
        ->pluck('field')
        ->toArray();
    }

    protected function relationIsUsingAccessorAsLabel($details)
    {
        return in_array($details->label, app($details->model)->additional_attributes ?? []);
    }
    
    public function projectsTable()
    {
        //dd(User::with('role')->get()->toArray());
        //$users = User::where("user_type",'web');
        $promos = Project::where("user_id",'=',Auth::User()->id);
       // $users = User::join("model_has_roles","model_has_roles.modal_id",'=',"users.id")->where("users.user_type",'web');
            return Datatables::of($promos)    
            ->addColumn('action', function ($user) {

                 //$hidetake = "display:none;";
                 $timeline = route("proTimeline")."?id=$user->id";
                 $hidetake = "";
                $b = "";        
                $chk = ($user->status=='1') ? "checked":"";
                if($user->installment_status!='completed')
                    $b .= '<div class="dropdown">
                          <button class="btn btn-warning dropdown-toggle" type="button" data-toggle="dropdown">
                          <span class="voyager-dot-3"></span></button>
                          <ul class="dropdown-menu">
                            <li><a href="javascript:edit('.$user->id.')"><i class="voyager-edit"></i> Edit</a></li>
                            <li><a href="javascript:delItem('.$user->id.')"><i class="voyager-trash"></i> Delete</a></li>
                            <li><a href="'.$timeline.'"><i class="voyager-list-add"></i> Timelines</a></li>
                          </ul>
                        </div>';
                //$b.= '<a onclick="del_client('.$user->id.')" href="javascript:;" class="btn btn-sm btn-danger danger-alert"><i class="fa fa-trash"></i></a> ';                                
                
                
                
                //$b.='<div class="my_switch make-switch"> <input type="checkbox" name="user_st" value="'.$user->id.'" checked /></div>';
                return $b;
            })
            
            
            ->rawColumns(['action'])
           // ->removeColumn('status')
            ->make(true);
    }
    public function delProject(Request $request)
    {
        $delObj = Project::here("user_id",'=',Auth::User()->id)->where("id",$request->id)->delete();
        if($delObj)
        {
            echo "1";
        }else
        {
            echo "0";
        }
        return "";
    }
    public function projectTimeline(Request $request)
    {
        $project = Project::where("user_id",'=',Auth::User()->id)->where("id",$request->id)->first();
        if($project)
        {
            $timelines = ProjectTimeline::where("pid",$project->id)->count();
           return view("projects.timelines",["project"=>$project,"timelines"=>$timelines]);
           
        }else
        {
             abort(401);
        }
    }
    public function timelineList(Request $request)
    {
        //dd(User::with('role')->get()->toArray());
        //$users = User::where("user_type",'web');
        $promos = ProjectTimeline::Join("projects","projects.id","=","project_timelines.pid")
        ->where("projects.user_id",'=',Auth::User()->id)
        ->where("project_timelines.pid",$request->pid)
        ->select(["project_timelines.id","project_timelines.timeline_name","project_timelines.created_at","projects.name"]);
       // $users = User::join("model_has_roles","model_has_roles.modal_id",'=',"users.id")->where("users.user_type",'web');
            return Datatables::of($promos)    
            ->addColumn('action', function($user) {

                 //$hidetake = "display:none;";
                 $timeline = route("timelineSingle")."?id=$user->id";
                 $hidetake = "";
                $b = "";        
                $chk = ($user->status=='1') ? "checked":"";
                if($user->installment_status!='completed')
                    $b .= '<div class="dropdown">
                          <button class="btn btn-warning dropdown-toggle" type="button" data-toggle="dropdown">
                          <span class="voyager-dot-3"></span></button>
                          <ul class="dropdown-menu">
                            <li><a href="javascript:delItem('.$user->id.')"><i class="voyager-trash"></i> Delete</a></li>
                            <li><a href="'.$timeline.'"><i class="voyager-file-text"></i> View Timeline</a></li>
                          </ul>
                        </div>';
                //$b.= '<a onclick="del_client('.$user->id.')" href="javascript:;" class="btn btn-sm btn-danger danger-alert"><i class="fa fa-trash"></i></a> ';                                
                
                
                
                //$b.='<div class="my_switch make-switch"> <input type="checkbox" name="user_st" value="'.$user->id.'" checked /></div>';
                return $b;
            })
            ->editColumn('created_at', function ($user) {

                 //$hidetake = "display:none;";
                 return $user->created_at->format("Y-m-d h:i a");
            })
            
            
            ->rawColumns(['action'])
           // ->removeColumn('status')
            ->make(true);
    }
    public function timlineOpt(Request $request)
    {
        $data["years"] = [];
        $data["months"] = [];
        //if($request->opt=='yearly' || $request->opt=='monthly')
        if($request->opt!='')
        {
            
          $range =  ProjectEvent::where("pid",$request->pid)
          ->select(DB::raw('Year(edate) as years'))
          ->groupBy(DB::raw('Year(edate)'))
          ->orderBy("years","asc")
          ->get();
          foreach($range as $year)
          {
            $data["years"][] = "Year ".$year->years;
          }
         // return $years;
        }
        if($request->opt=='monthly' || $request->opt=='weekly')
        {
            
          $range =  ProjectEvent::where("pid",$request->pid)
          ->select(DB::raw('date_format(edate,"%b") as months'))
          ->groupBy('months')
          ->orderBy(DB::raw('month(edate)'),"asc")
          ->get();
          foreach($range as $year)
          {
            $data["months"][] = $year->months;
          }
         // return $years;
        }
        return $data;
    }
    
    public function timelineSave(Request $request)
    {
        $monthsArray = [
        "Jan"=>1,
        "Feb"=>2,
        "Mar"=>3,
        "Apr"=>4,
        "May"=>5,
        "Jun"=>6,
        "Jul"=>7,
        "Aug"=>8,
        "Sep"=>9,
        "Oct"=>10,
        "Nov"=>11,
        "Dec"=>12
        ]; 
        try{
                           
                $timeline = new ProjectTimeline;
    
                if($request->id!='')
                {
                    $timeline = $timeline->findOrFail($request->id);
                }
               
               $timeline->timeline_name = $request->timeline_name;
               $timeline->sub_title = $request->sub_title;
                
                $timeline->pid = $request->pid;
                $timeline->period = $request->period;
                if(isset($request->tyears))
                {
                    $years =  explode(';',$request->tyears);
                    $years = str_replace("Year ","",$years);
                    $timeline->start_year = $years[0];
                    $timeline->end_year = $years[1];
                }
                
                
                if(isset($request->tmonths))
                {
                    $monhts =  explode(';',$request->tmonths);
                   // $years = str_replace("Year ","",$years);
                    $timeline->start_month = $monthsArray[$monhts[0]];
                    $timeline->end_month = $monthsArray[$monhts[1]];
                }
                
                if($timeline->save())
                {
                     return response()->json(['success'=>true,"message"=>"Timeline Successfully saved!"]); 
                    
                }else
                {
                     return response()->json(['success'=>false,"message"=>"error while saving timline!"]);    
                }   
                   
            } catch (Exception $e) {
                            
                return response()->json(['success'=>false,"message"=>$e->getMessage()]);
            }
           
              
       
        
    }
    
    public function timelineSingle(Request $request)
    {
        $projectTimeline = ProjectTimeline::where("id",$request->id)->first();
        $realEvents = [];
        if($projectTimeline)
        {
            $project = Project::where("user_id",'=',Auth::User()->id)->where("id",$projectTimeline->pid)->first();
            if($project)
            {
                if($projectTimeline->period=='yearly')
                {
                     $events = ProjectEvent::select(DB::raw('Year(edate) as yr'),"project_events.*")
                     ->whereRaw("pid=$project->id and year(edate) between $projectTimeline->start_year and $projectTimeline->end_year")
                     ->orderBy("yr","asc")
                     ->get();
                      foreach($events as $event)
                      {
                        $realEvents[$event->yr][]=$event;
                      }
                }
                
                if($projectTimeline->period=='monthly')
                {
                     $events = ProjectEvent::select(DB::raw('Year(edate) as yr'),DB::raw('date_format(edate,"%b") as month'),"project_events.*")
                     ->whereRaw("pid=$project->id and year(edate) between $projectTimeline->start_year and $projectTimeline->end_year and month(edate) between '$projectTimeline->start_month' and '$projectTimeline->end_month'")
                     ->orderBy('edate',"asc")
                     ->get();
                      foreach($events as $event)
                      {
                        $realEvents[$event->month." ".$event->yr][]=$event;
                      }
                }
                
                if($projectTimeline->period=='weekly')
                {
                     $events = ProjectEvent::select(DB::raw('Year(edate) as yr'),DB::raw('date_format(edate,"%b") as month'),DB::raw('WEEK(edate,1) as week'),"project_events.*")
                     ->whereRaw("pid=$project->id and year(edate) between $projectTimeline->start_year and $projectTimeline->end_year and month(edate) between '$projectTimeline->start_month' and '$projectTimeline->end_month'")
                     ->orderBy('edate',"asc")
                     ->get();
                      foreach($events as $event)
                      {
                        $realEvents[$event->yr." ".$event->month." Week ".$event->week][]=$event;
                      }
                }
               
                
                /*$years =  ProjectEvent::whereRaw("pid=$project->id and year(edate) between $projectTimeline->start_year and $projectTimeline->end_year")
                  ->select(DB::raw('Year(edate) as years'))
                  ->groupBy(DB::raw('Year(edate)'))
                  ->orderBy("years","asc")
                  ->get()->toArray();*/
                  
                  
                  
                 // dd($realEvents);
                //return view("projects.timeline",["project"=>$project,"timeline"=>$projectTimeline,"years"=>$years]);
                return view("projects.timeline",["project"=>$project,"timeline"=>$projectTimeline,"timelineEvents"=>$realEvents]);
               
            }else
            {
                 abort(401);
            }

        }else
        {
             abort(401);
        }
    }
    public function timelinePdf(Request $request)
    {
        $projectTimeline = ProjectTimeline::where("id",$request->id)->first();
        if($projectTimeline)
        {
            $project = Project::where("user_id",'=',Auth::User()->id)->where("id",$projectTimeline->pid)->first();
            if($project)
            {
                $events = ProjectEvent::select(DB::raw('Year(edate) as yr'),"project_events.*")
                ->whereRaw("pid=$project->id and year(edate) between $projectTimeline->start_year and $projectTimeline->end_year")
                ->orderBy("yr","asc")
                ->get();
                
                /*$years =  ProjectEvent::whereRaw("pid=$project->id and year(edate) between $projectTimeline->start_year and $projectTimeline->end_year")
                  ->select(DB::raw('Year(edate) as years'))
                  ->groupBy(DB::raw('Year(edate)'))
                  ->orderBy("years","asc")
                  ->get()->toArray();*/
                  
                  $realEvents = [];
                  foreach($events as $event)
                  {
                    $realEvents[$event->yr][]=$event;
                  }
                 // dd($realEvents);
                  //$pdf = Pdf::loadView('projects.timelinepdf', ["project"=>$project,"timeline"=>$projectTimeline,"timelineEvents"=>$realEvents]);
                  //$html = view("projects.timelinepdf",["project"=>$project,"timeline"=>$projectTimeline,"timelineEvents"=>$realEvents]);
                  //$pdf =  Pdf::loadHTML($html)->setPaper('a4', 'landscape')->setWarnings(false);
                 // return $pdf->stream();
                //return view("projects.timeline",["project"=>$project,"timeline"=>$projectTimeline,"years"=>$years]);
                return view("projects.timelinepdf",["project"=>$project,"timeline"=>$projectTimeline,"timelineEvents"=>$realEvents]);
               
            }else
            {
                 abort(401);
            }

        }else
        {
             abort(401);
        }
    }
    
    
}
