@extends('voyager::master')

@section('page_title', __('voyager::generic.'.(isset($dataTypeContent->id) ? 'edit' : 'add')).' '.$dataType->getTranslatedAttribute('display_name_singular'))

@section('css')
    <meta name="csrf-token" content="{{ csrf_token() }}">
    <link href="//cdn.datatables.net/1.12.1/css/dataTables.bootstrap.min.css" type="text/css" />
    <link href="//cdn.datatables.net/fixedheader/3.2.4/css/fixedHeader.bootstrap.min.css" type="text/css" />
    <style>
    .modal-backdrop {
        z-index: 1000 !important;
    }
    .swal2-container{
        z-index : 100002 !important;
    }
    
    </style>
@stop

@section('page_header')
    <h1 class="page-title">
        <i class="{{ $dataType->icon }}"></i>
        Projects
    </h1>
    <?php
            $show = true;
                if(!auth()->user()->hasRole('admin'))
                {
                    $plan = auth()->user()->subscriptionPlan();
                    if($plan)
                    {
                        
                       
                        if($plan['plan']->total_projects>$projects)
                        {
                            $show = true;
                        }else
                        {
                            $show = false;
                        }
                    }     
                }
    ?>
       @can('add', app($dataType->model_name))
            @if($show)
            <a href="javascript:addProject()" class="btn btn-success btn-add-new">
                <i class="voyager-plus"></i> <span>{{ __('voyager::generic.add_new') }}</span>
            </a>
            @endif
        @endcan
@stop

@section('content')
    <div class="page-content browse container-fluid">
        
        <div class="row">
            <div class="col-md-12">

                <div class="panel panel-bordered">
                    <div class="panel-body">
                            <table id="dataTable" class="table table-hover">
                                <thead>
                                    <tr>
                                        <th>ID</th>
                                        <th>Project Name</th>
                                                                          
                                        <th class="actions  dt-not-orderable">Action</th>
                                    </tr>
                                </thead>
                                <tbody></tbody>
                            </table>
                        </div>

                </div>
            </div>
        </div>
       
        
    </div>
    <div id="promodal" role="dialog" class="modal modal-info fade in" style="display: none;">
       
        <div class="modal-dialog">
            <div class="modal-content">
				<div class="modal-header">
					<button type="button" data-dismiss="modal" aria-label="Close" class="close"><span aria-hidden="true">x</span></button>
					<h4 class="modal-title">
						<i class="{{ $dataType->icon }}">
						</i>
						Save Project
					</h4>
				</div>
				<div class="modal-body" >
					 <form id='projectform' enctype="multipart/form-data">
                     @csrf
                     <input type="hidden" name="id" />
                          <div class="form-group">
                            <label  class="control-label"
                                      for="pname">Project Name</label>
                            <div class="">
                                <input type="text" required="" name="name" class="form-control" 
                                id="pname" placeholder="Project name"/>
                            </div>
                          </div>
                          
                           <div class="form-group" id="fileInp">
                                <label for="exampleInputFile">Select File</label>
                                <div class="">
                                    <input type="file" name="file" id="exampleInputFile">
                                    <p class="help-block">Only csv files are allowed.</p>
                                </div>
                           </div>
                         
                    </form>
				</div>
				<div class="modal-footer">
                    <button form="projectform"  type="submit" class="btn btn-info  pull-right">Save</button>                  
				</div>
			</div>
        </div>
			
    </div>
@stop

@section('javascript')
<script src="//cdn.datatables.net/1.12.1/js/dataTables.bootstrap.min.js"></script>
<script src="//malsup.github.io/jquery.blockUI.js"></script>
<script src="//cdn.jsdelivr.net/npm/sweetalert2@11"></script>

    <script>
    function addProject()
    {
        $("#fileInp").show();        
        $('#promodal').modal('show');
        $("#projectform")[0].reset();
        $("input[name='id']").val('');
        
    }
    function edit(id)
    {
       
        blockUI('.page-content');
        $("#fileInp").hide();                
        $.get("{{route('voyager.projects.index')}}/"+id,function(res){
                //Swal.hideLoading();
                $('.page-content').unblock();
                 $('#promodal').modal('show');                                
                if(res!='')
                {
                    $("input[name='id']").val(res.id);
                    $("input[name='name']").val(res.name);                    
                }else
                {
                    //Swal.fire('Error!', 'Error while deleting project!', 'error')
                }
                
            })
        
    }    
        
    function delItem(id)
    {
        Swal.fire({
             icon: "warning",
          title: 'Are you sure?',
          text: "Once deleted, you will not be able to recover this!",
          //showDenyButton: true,
          confirmButtonColor: '#3085d6',
          cancelButtonColor: '#d33',
          confirmButtonText: 'Yes, delete it!',
          showCancelButton: true,
          
          
         // denyButtonText: `Don't save`,
        }).then((result) => {
          /* Read more about isConfirmed, isDenied below */
          if (result.isConfirmed) {
            
            Swal.showLoading();
            $.get("{{route('delporject')}}",{id:id},function(res){
                Swal.hideLoading();
                if(res=='1')
                {
                    Swal.fire('Good Job!', 'Project successfully deleted!', 'success');
                    $("#dataTable").DataTable().ajax.reload();                    
                }else
                {
                    Swal.fire('Error!', 'Error while deleting project!', 'error')
                }
                
            })
          } 
        });
    }
        
    function blockUI(cls) {
    $(cls).block({
      
      message: '<h2 style="margin-bottom: 20px;"> processing... </h2>',
      css: { 
            border: 'none', 
          //  paddingTop: '15px', 
            backgroundColor: '#000', 
            '-webkit-border-radius': '10px', 
            '-moz-border-radius': '10px', 
            opacity: .5, 
            color: '#fff',
            width:"50%",
        }
      //baseZ: 100003,
      
    });
    //$('.blockUI.blockMsg').center();
  }
        $('document').ready(function () {
            $('#dataTable').DataTable({
                    "order": [[ 0, 'desc' ]],
                     processing: true,
                    serverSide: true,
                    
                    ajax: "{!! Route('getProjects') !!}",
                    columns: [
                        { data: 'id', name: 'id' },
                        { data: 'name', name: 'name' },
                        
                        { data: 'action', name: 'action', orderable: false, searchable: false }
                        //{ data: 'updated_at', name: 'updated_at' }
                    ]
                    
                });
           $("#projectform").submit(function(){
                var formData = new FormData(this);
                    //formData.append('file', $('#file')[0].files[0]);
                    blockUI('.modal-content');
                    $.ajax({
                           url : '{{ route("voyager.projects.store") }}',
                           type : 'POST',
                           data : formData,
                           processData: false,  // tell jQuery not to process the data
                           contentType: false,  // tell jQuery not to set contentType
                            //async: false,
                           complete:function(){
                            $('.modal-content').unblock();
                           },
                           success : function(data) {
                            if(data.success==true)
                            {
                                Swal.fire("Good job!", "Project Successfully saved!", "success");
                                $('#promodal').modal('hide')
                                $("#projectform")[0].reset();
                                $("input[name='id']").val('');
                                $("#dataTable").DataTable().ajax.reload();
                            }else
                            {
                                Swal.fire("Error!", data.message, "error");
                            }
                            
                               //console.log(data);
                               //alert(data);
                           }
                    });
                    return false;
           });     
        });
    </script>
@stop
